@@ -1,23 +1,26 @@
+from pathlib import Path
 from typing import (
     Tuple,
     Dict,
     List,
-    Iterator,
     Iterable,
     Optional,
     Any
 )
-from pathlib import Path
+
 import click
 import toml
 
-from robotidy.version import __version__
 from robotidy.app import Robotidy
 from robotidy.transformers import load_transformers
-from robotidy.utils import GlobalFormattingConfig, split_args_from_name_or_path
+from robotidy.utils import (
+    GlobalFormattingConfig,
+    split_args_from_name_or_path,
+    remove_rst_formatting
+)
+from robotidy.version import __version__
 
 
-INCLUDE_EXT = ('.robot', '.resource')
 HELP_MSG = f"""
 Version: {__version__}
 
@@ -34,10 +37,10 @@ Examples:
   $ robotidy dir_name
 
   # List available transformers:
-  $ robotidy --list-transformers
+  $ robotidy --list
   
   # Display transformer documentation
-  $ robotidy --describe-transformer <TRANSFORMER_NAME>
+  $ robotidy --desc <TRANSFORMER_NAME>
 
   # Format `src.robot` file using `SplitTooLongLine` transformer only
   $ robotidy --transform SplitTooLongLine src.robot
@@ -106,92 +109,86 @@ def find_project_root(srcs: Iterable[str]) -> Path:
         if (directory / "robotidy.toml").is_file():
             return directory
 
+        if (directory / "pyproject.toml").is_file():
+            return directory
+
     return directory
 
 
-def find_config(src_paths: Iterable[str]) -> Optional[str]:
+def find_and_read_config(src_paths: Iterable[str]) -> Dict[str, Any]:
     project_root = find_project_root(src_paths)
     config_path = project_root / 'robotidy.toml'
-    return str(config_path) if config_path.is_file() else None
+    if config_path.is_file():
+        return read_robotidy_config(str(config_path))
+    pyproject_path = project_root / 'pyproject.toml'
+    if pyproject_path.is_file():
+        return read_pyproject_config(str(pyproject_path))
+    return {}
+
+
+def load_toml_file(path: str) -> Dict[str, Any]:
+    try:
+        config = toml.load(path)
+        click.echo(f"Loaded configuration from {path}")
+        return config
+    except (toml.TomlDecodeError, OSError) as e:
+        raise click.FileError(
+            filename=path, hint=f"Error reading configuration file: {e}"
+        )
+
+
+def read_pyproject_config(path: str) -> Dict[str, Any]:
+    click.echo('Reading pyproject.toml')
+    config = load_toml_file(path)
+    config = config.get("tool", {}).get("robotidy", {})
+    return {k.replace('--', '').replace('-', '_'): v for k, v in config.items()}
+
+
+def read_robotidy_config(path: str) -> Dict[str, Any]:
+    config = load_toml_file(path)
+    return {k.replace('--', '').replace('-', '_'): v for k, v in config.items()}
 
 
 def read_config(ctx: click.Context, param: click.Parameter, value: Optional[str]) -> Optional[str]:
-    # if --config was not used, try to find robotidy.toml file
-    if not value:
-        value = find_config(ctx.params.get("src", ()))
-        if value is None:
-            return None
-    try:
-        config = parse_config(value)
-    except (toml.TomlDecodeError, OSError) as e:
-        raise click.FileError(
-            filename=value, hint=f"Error reading configuration file: {e}"
-        )
-    click.echo(f'Reading config from {value}')
-    if not config:
-        return None
+    # if --config was not used, try to find pyproject.toml or robotidy.toml file
+    if value:
+        config = read_robotidy_config(value)
     else:
-        # Sanitize the values to be Click friendly. For more information please see:
-        # https://github.com/psf/black/issues/1458
-        # https://github.com/pallets/click/issues/1567
-        config = {
-            k: str(v) if not isinstance(v, (list, dict)) else v
-            for k, v in config.items()
-        }
+        config = find_and_read_config(ctx.params.get("src", ()))
+    if not config:
+        return
+    # Sanitize the values to be Click friendly. For more information please see:
+    # https://github.com/psf/black/issues/1458
+    # https://github.com/pallets/click/issues/1567
+    config = {
+        k: str(v) if not isinstance(v, (list, dict)) else v
+        for k, v in config.items()
+    }
 
     default_map: Dict[str, Any] = {}
     if ctx.default_map:
         default_map.update(ctx.default_map)
-    default_map.update(config.get('main', {}))
-
-    transformers = []
-    for transformer, configurables in config.get('transformers', {}).items():
-        if configurables:
-            transformer += ':' + ':'.join(f'{key}={value}' for key, value in configurables.items())
-        transformers.append(transformer)
-    default_map['transform'] = transformers
-
+    default_map.update(config)
     ctx.default_map = default_map
-    return value
-
-
-def parse_config(path: str) -> Dict[str, Any]:
-    config = toml.load(path)
-    return {k.replace('--', '').replace('-', '_'): v for k, v in config.items()}
-
-
-def iterate_dir(paths: Iterable[Path]) -> Iterator[Path]:
-    for path in paths:
-        if path.is_file():
-            if path.suffix not in INCLUDE_EXT:
-                continue
-            yield path
-        elif path.is_dir():
-            yield from iterate_dir(path.iterdir())
-
-
-def get_paths(src: Tuple[str, ...]):
-    sources = set()
-    for s in src:
-        path = Path(s).resolve()
-        if path.is_file():
-            sources.add(path)
-        elif path.is_dir():
-            sources.update(iterate_dir(path.iterdir()))
-        elif s == '-':
-            sources.add(path)
-
-    return sources
 
 
 @click.command(cls=RawHelp, help=HELP_MSG, epilog=EPILOG)
 @click.option(
     '--transform',
+    '-t',
     type=TransformType(),
     multiple=True,
     metavar='TRANSFORMER_NAME',
     help="Transform files from [PATH(S)] with given transformer"
 )
+@click.option(
+    '--configure',
+    '-c',
+    type=TransformType(),
+    multiple=True,
+    metavar='TRANSFORMER_NAME:PARAM=VALUE',
+    help='Configure transformers'
+)
 @click.argument(
     "src",
     nargs=-1,
@@ -239,13 +236,6 @@ def get_paths(src: Tuple[str, ...]):
          "unix:    use Unix line separators (LF)",
     show_default=True
 )
-@click.option(
-    '-p',
-    '--usepipes',
-    is_flag=True,
-    help="Use pipe ('|') as a column separator in the plain text format.",
-    show_default=True
-)
 @click.option(
     '-sl',
     '--startline',
@@ -286,12 +276,16 @@ def get_paths(src: Tuple[str, ...]):
 )
 @click.option(
     '--list-transformers',
+    '--list',
+    '-l',
     is_eager=True,
     is_flag=True,
     help='List available transformers and exit.'
 )
 @click.option(
     '--describe-transformer',
+    '--desc',
+    '-d',
     default=None,
     metavar='TRANSFORMER_NAME',
     help='Show documentation for selected transformer.'
@@ -300,14 +294,14 @@ def get_paths(src: Tuple[str, ...]):
 @click.pass_context
 def cli(
         ctx: click.Context,
-        transform: List[Tuple[str, Dict]],
+        transform: List[Tuple[str, List]],
+        configure: List[Tuple[str, List]],
         src: Tuple[str, ...],
         overwrite: bool,
         diff: bool,
         check: bool,
         spacecount: int,
         lineseparator: str,
-        usepipes: bool,
         verbose: bool,
         config: Optional[str],
         startline: Optional[int],
@@ -316,16 +310,17 @@ def cli(
         describe_transformer: Optional[str]
 ):
     if list_transformers:
-        transformers = load_transformers(None)
-        click.echo('Run --describe-transformer <transformer_name> to get more details. Transformers:')
+        transformers = load_transformers(None, {})
+        click.echo('Run --desc <transformer_name> to get more details. Transformers:')
         for transformer in transformers:
-            click.echo(transformer)
+            click.echo(transformer.__class__.__name__)
         ctx.exit(0)
     if describe_transformer is not None:
-        transformers = load_transformers(None)
-        if describe_transformer in transformers:
+        transformers = load_transformers(None, {})
+        transformer_by_names = {transformer.__class__.__name__: transformer for transformer in transformers}
+        if describe_transformer in transformer_by_names:
             click.echo(f"Transformer {describe_transformer}:")
-            click.echo(transformers[describe_transformer].__doc__)
+            click.echo(remove_rst_formatting(transformer_by_names[describe_transformer].__doc__))
         else:
             click.echo(f"Transformer with the name '{describe_transformer}' does not exist")
         ctx.exit(0)
@@ -334,16 +329,15 @@ def cli(
         click.echo(f'Loaded {config} configuration file')
 
     formatting_config = GlobalFormattingConfig(
-        use_pipes=usepipes,
         space_count=spacecount,
         line_sep=lineseparator,
         start_line=startline,
         end_line=endline
     )
-    sources = get_paths(src)
     tidy = Robotidy(
         transformers=transform,
-        src=sources,
+        transformers_config=configure,
+        src=src,
         overwrite=overwrite,
         show_diff=diff,
         formatting_config=formatting_config,
