@@ -6,7 +6,12 @@ from robot.api.parsing import (
 )
 from robot.parsing.model import Statement
 
-from robotidy.decorators import check_start_end_line
+from robotidy.utils import (
+    node_outside_selection,
+    round_to_four,
+    tokens_by_lines,
+    left_align
+)
 
 
 class AlignVariablesSection(ModelTransformer):
@@ -21,7 +26,7 @@ class AlignVariablesSection(ModelTransformer):
         &{MULTILINE}  a=b
         ...  b=c
 
-    Will be transformed to::
+    will be transformed to::
 
         *** Variables ***
         ${VAR}          1
@@ -29,16 +34,30 @@ class AlignVariablesSection(ModelTransformer):
         &{MULTILINE}    a=b
         ...             b=c
 
+    You can configure how many columns should be aligned to longest token in given column. The remaining columns
+    will use fixed length separator length ``--space_count``. By default only first two columns are aligned.
+    To align first three columns::
+
+       robotidy --transform AlignVariablesSection:up_to_column=3
+
+    To align all columns set ``up_to_column` to 0.
+
     Supports global formatting params: ``--startline`` and ``--endline``.
     """
-    @check_start_end_line
+    def __init__(self, up_to_column: int = 2):
+        self.up_to_column = up_to_column - 1
+
     def visit_VariableSection(self, node):  # noqa
+        if node_outside_selection(node, self.formatting_config):
+            return node
         statements = []
         for child in node.body:
-            if child.type in (Token.EOL, Token.COMMENT):
+            if node_outside_selection(child, self.formatting_config):
                 statements.append(child)
+            elif child.type in (Token.EOL, Token.COMMENT):
+                statements.append(left_align(child))
             else:
-                statements.append(list(self.tokens_by_lines(child)))
+                statements.append(list(tokens_by_lines(child)))
         nodes_to_be_aligned = [st for st in statements if isinstance(st, list)]
         if not nodes_to_be_aligned:
             return node
@@ -54,9 +73,12 @@ class AlignVariablesSection(ModelTransformer):
                 continue
             aligned_statement = []
             for line in st:
+                up_to = self.up_to_column if self.up_to_column != -1 else len(line) - 2
                 for index, token in enumerate(line[:-2]):
                     aligned_statement.append(token)
-                    aligned_statement.append(Token(Token.SEPARATOR, (look_up[index] - len(token.value) + 4) * ' '))
+                    separator = (look_up[index] - len(token.value) + 4) * ' ' if index < up_to else \
+                        self.formatting_config.space_count * ' '
+                    aligned_statement.append(Token(Token.SEPARATOR, separator))
                 last_token = line[-2]
                 # remove leading whitespace before token
                 last_token.value = last_token.value.strip() if last_token.value else last_token.value
@@ -65,28 +87,11 @@ class AlignVariablesSection(ModelTransformer):
             aligned_statements.append(Statement.from_tokens(aligned_statement))
         return aligned_statements
 
-    def tokens_by_lines(self, node):
-        for index, line in enumerate(node.lines):
-            if line:
-                if line[0].type == Token.VARIABLE and not line[0].value:
-                    # if variable is prefixed with spaces
-                    line = line[1:]
-                elif line[0].type == Token.ARGUMENT:
-                    line[0].value = line[0].value.strip() if line[0].value else line[0].value
-            yield [token for token in line if token.type not in ('SEPARATOR', 'EOS')]
-
-    @staticmethod
-    def create_look_up(statements):
+    def create_look_up(self, statements):
         look_up = defaultdict(int)
         for st in statements:
             for line in st:
-                for index, token in enumerate(line):
+                up_to = self.up_to_column if self.up_to_column != -1 else len(line)
+                for index, token in enumerate(line[:up_to]):
                     look_up[index] = max(look_up[index], len(token.value))
-        return {index: AlignVariablesSection.round_to_four(length) for index, length in look_up.items()}
-
-    @staticmethod
-    def round_to_four(number):
-        div = number % 4
-        if div:
-            return number + 4 - div
-        return number
+        return {index: round_to_four(length) for index, length in look_up.items()}
